#
# spec file for package libart_lgpl
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libart_lgpl
Version:        2.3.21
Release:        25.4
# NOTE: on upgrade to a new upstream version, change the Obsoletes from <= to <
Summary:        Libart Components Licensed under the LGPL
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
Source:         https://download.gnome.org/sources/%{name}/2.3/%{name}-%{version}.tar.bz2
BuildRequires:  pkgconfig

%description
Libart is a library for high-performance 2D graphics. It is currently
being used as the antialiased rendering engine for GNOME Canvas. It is
also the rendering engine for Gill, the GNOME Illustration application.

%package -n libart_lgpl_2-2
Summary:        Libart Components Licensed under the LGPL
Group:          System/Libraries
Provides:       %{name} = %{version}
# Note: we keep <= (and a rpmlint warning...) until we get a version higher than 2.3.21 (when this provides/obsoletes was introduced)
Obsoletes:      %{name} <= %{version}
#

%description -n libart_lgpl_2-2
Libart is a library for high-performance 2D graphics. It is currently
being used as the antialiased rendering engine for GNOME Canvas. It is
also the rendering engine for Gill, the GNOME Illustration application.

%package devel
Summary:        Header files for the libart 2D graphics library
Group:          System/GUI/GNOME
Requires:       libart_lgpl_2-2 = %{version}

%description devel
This package contains the header files for developing
applications that want to make use of libart_lgpl.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libart_lgpl_2-2 -p /sbin/ldconfig
%postun -n libart_lgpl_2-2 -p /sbin/ldconfig

%files -n libart_lgpl_2-2
%license COPYING
%doc AUTHORS README NEWS ChangeLog
%{_libdir}/*.so.*

%files devel
%{_bindir}/*-config
%{_includedir}/libart-2.0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Mon Aug  2 2021 Yifan Jiang <yfjiang@suse.com>
- Update a valid URL of the Source field in spec.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Remove --with-pic which is useless with --disable-static.
- Replace boilerplate descriptions from a decade ago.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Fri Sep 16 2011 jengelh@medozas.de
- Add libart_lgpl-devel to baselibs
- Remove redundant tags/sections; use %%_smp_mflags
* Mon Oct 11 2010 vuntz@opensuse.org
- Update packaging to use the shared library packaging policy:
  + Create libart_lgpl_2-2 subpackage.
  + Add Provides/Obsoletes for libart_lgpl to libart_lgpl_2-2.
  + Update baselibs.conf accordingly.
* Thu Apr  1 2010 vuntz@opensuse.org
- Update to version 2.3.21:
  + Allow crosscompiling without using different emulators
- Remove call to autoreconf.
- Use makeinstall macro.
* Wed Dec 16 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Sat Feb 14 2009 mboman@suse.de
- Keep "la" files for <= 11.1
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Feb 18 2008 maw@suse.de
- Update to version 2.3.20:
  + Fix the inclusion of art_misc.h from c++
- Remove fix-headers.diff.
* Mon Mar 26 2007 dmueller@suse.de
- Fix the installed headers again
* Wed Mar 21 2007 maw@suse.de
- Update to version 2.3.19
- b.g.o fixes: 131478, 317562, and 301750.
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb  4 2005 gekker@suse.de
- Update to version 2.3.17
* Wed Aug 25 2004 kukuk@suse.de
- call ldconfig directly and avoid /bin/sh prereq
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon Oct  6 2003 sbrabec@suse.cz
- Updated to version 2.3.16.
* Mon Aug 18 2003 sbrabec@suse.cz
- Updated to version 2.3.14.
* Tue Jul 29 2003 adrian@suse.de
- fix build
* Wed Jul 16 2003 sbrabec@suse.cz
- Prefix changed back to /usr on request of KDE maintainers.
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 12 2003 sbrabec@suse.cz
- Updated to version 2.3.12.
* Wed Jan 15 2003 hhetter@suse.de
- updated to version 2.3.11
* Thu Oct 24 2002 hhetter@suse.de
- use automake -c to copy files, not link
  (Bug Id #21066)
* Mon Oct 21 2002 sbrabec@suse.cz
- Updated %%files (libart_lgpl/libart_lgpl-devel splitting).
* Tue Jul 23 2002 hhetter@suse.de
- updated to 2.3.10
* Wed Jul 17 2002 hhetter@suse.de
- fix filelist
* Thu Jun 27 2002 hhetter@suse.de
- updated to version 2.3.9 (gnome 2.0 final)
  * platform build fixes
  * minor bugfixes
* Wed Jun 19 2002 ro@suse.de
- use "-a -f" for automake
* Fri Apr 26 2002 coolo@suse.de
- use %%_libdir
* Mon Jan 14 2002 hhetter@suse.de
- updated to version 2.3.8:
  * new functions
  * some header files corrected
  * Makefile improvements
* Wed Jan  9 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
